/* auto.c - Main source file.

 * Copyright (c) 2005 Devin Smith
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:

 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.

 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.

 */

/*<---------------------------------------------------------------------->*/
#include "apisres.h"
#include "auto.h"

#define DF_WIDTH 800
#define DF_HEIGHT 600
/*<---------------------------------------------------------------------->*/
HINSTANCE gInst;                // Instance handle
HWND hwndMain;          //Main window handle
HWND hwndMDIClient;		//Mdi client window handle

LRESULT CALLBACK MainWndProc(HWND hwnd,UINT msg,WPARAM wParam,LPARAM lParam);
LRESULT CALLBACK MdiChildWndProc(HWND hwnd,UINT msg,WPARAM wparam,LPARAM lparam);
static HWND CreateMdiClient(HWND hwndparent);
void setupReports();

// Global Variables for the status bar control.

HWND  hWndStatusbar;

BOOL isConnected = FALSE;
BOOL useDatabase = TRUE;
static BOOL bStartup;
BOOL bsLook;

char loginID[80];

/* Reports URL */

char reports1[256];
char reports2[256];
char reports3[256];


/*------------------------------------------------------------------------
 Procedure:     UpdateStatusBar ID:1
 Purpose:       Updates the statusbar control with the appropiate
		text
 Input:         lpszStatusString: Charactar string that will be shown
		partNumber: index of the status bar part number.
		displayFlags: Decoration flags
 Output:        none
 Errors:        none

------------------------------------------------------------------------*/
void UpdateStatusBar(LPSTR lpszStatusString, WORD partNumber, WORD displayFlags)
{
    SendMessage(hWndStatusbar,
		SB_SETTEXT,
		partNumber | displayFlags,
		(LPARAM)lpszStatusString);
}


/*------------------------------------------------------------------------
 Procedure:     MsgMenuSelect ID:1
 Purpose:       Shows in the status bar a descriptive explaation of
		the purpose of each menu item.The message
		WM_MENUSELECT is sent when the user starts browsing
		the menu for each menu item where the mouse passes.
 Input:         Standard windows.
 Output:        The string from the resources string table is shown
 Errors:        If the string is not found nothing will be shown.
------------------------------------------------------------------------*/
LRESULT MsgMenuSelect(HWND hwnd, UINT uMessage, WPARAM wparam, LPARAM lparam)
{
    static char szBuffer[256];
    UINT   nStringID = 0;
    UINT   fuFlags = GET_WM_MENUSELECT_FLAGS(wparam, lparam) & 0xffff;
    UINT   uCmd    = GET_WM_MENUSELECT_CMD(wparam, lparam);
    HMENU  hMenu   = GET_WM_MENUSELECT_HMENU(wparam, lparam);

    szBuffer[0] = 0;                            // First reset the buffer
    if (fuFlags == 0xffff && hMenu == NULL)     // Menu has been closed
	nStringID = 0;

    else if (fuFlags & MFT_SEPARATOR)           // Ignore separators
	nStringID = 0;

    else if (fuFlags & MF_POPUP)                // Popup menu
    {
	if (fuFlags & MF_SYSMENU)               // System menu
	    nStringID = IDS_SYSMENU;
	else
	    // Get string ID for popup menu from idPopup array.
	    nStringID = 0;
    }  // for MF_POPUP
    else                                        // Must be a command item
	nStringID = uCmd;                       // String ID == Command ID

    // Load the string if we have an ID
    if (0 != nStringID)
	LoadString(gInst, nStringID, szBuffer, sizeof(szBuffer));
    // Finally... send the string to the status bar
    UpdateStatusBar(szBuffer, 0, 0);
    return 0;
}


/*------------------------------------------------------------------------
 Procedure:     InitializeStatusBar ID:1
 Purpose:       Initialize the status bar
 Input:         hwndParent: the parent window
		nrOfParts: The status bar can contain more than one
		part. What is difficult, is to figure out how this
		should be drawn. So, for the time being only one is
		being used...
 Output:        The status bar is created
 Errors:
------------------------------------------------------------------------*/
void InitializeStatusBar(HWND hwndParent,int nrOfParts)
{
//    const int cSpaceInBetween = 8;
    int   ptArray[40];   // Array defining the number of parts/sections
    RECT  rect;
    HDC   hDC;

   /* * Fill in the ptArray...  */

    hDC = GetDC(hwndParent);
    GetClientRect(hwndParent, &rect);

    ptArray[nrOfParts-1] = rect.right;
    //---TODO--- Add code to calculate the size of each part of the status
    // bar here.

    ReleaseDC(hwndParent, hDC);
    SendMessage(hWndStatusbar,
		SB_SETPARTS,
		nrOfParts,
		(LPARAM)(LPINT)ptArray);

    UpdateStatusBar("Ready", 0, 0);
    //---TODO--- Add code to update all fields of the status bar here.
    // As an example, look at the calls commented out below.

//    UpdateStatusBar("Cursor Pos:", 1, SBT_POPOUT);
//    UpdateStatusBar("Time:", 3, SBT_POPOUT);
}


/*------------------------------------------------------------------------
 Procedure:     CreateSBar ID:1
 Purpose:       Calls CreateStatusWindow to create the status bar
 Input:         hwndParent: the parent window
		initial text: the initial contents of the status bar
 Output:
 Errors:
------------------------------------------------------------------------*/
static BOOL CreateSBar(HWND hwndParent,char *initialText,int nrOfParts)
{
    hWndStatusbar = CreateStatusWindow(WS_CHILD | WS_VISIBLE | WS_BORDER|SBARS_SIZEGRIP,
				       initialText,
				       hwndParent,
				       IDM_STATUSBAR);
    if(hWndStatusbar)
    {
	InitializeStatusBar(hwndParent,nrOfParts);
	return TRUE;
    }

    return FALSE;
}

/*<---------------------------------------------------------------------->*/
/*@@0->@@*/
static BOOL InitApplication(void)
{
	WNDCLASS wc;

	memset(&wc,0,sizeof(WNDCLASS));
	wc.style = CS_HREDRAW | CS_VREDRAW |CS_DBLCLKS ;
	wc.lpfnWndProc = (WNDPROC)MainWndProc;
	wc.hInstance = gInst;
	wc.hbrBackground = (HBRUSH)(DKGRAY_BRUSH+1);
	wc.lpszClassName = "MainWndClass";
	wc.lpszMenuName = MAKEINTRESOURCE(IDMAINMENU);
	wc.hCursor = LoadCursor(NULL,IDC_ARROW);
	wc.hIcon = LoadIcon(gInst,MAKEINTRESOURCE(IDAPPLICON));
	if (!RegisterClass(&wc))
		return 0;

    /* Code to build child MDI windows */
	wc.style         = CS_HREDRAW | CS_VREDRAW;
	wc.lpfnWndProc   = (WNDPROC)MdiChildWndProc;
	wc.cbClsExtra    = 0;
	wc.cbWndExtra    = 20;
	wc.hInstance     = gInst;                      // Owner of this class
	wc.hIcon         = LoadIcon(gInst, MAKEINTRESOURCE(IDAPPLICON));
	wc.hCursor       = LoadCursor(NULL, IDC_ARROW);
	wc.hbrBackground = (HBRUSH)(LTGRAY_BRUSH); // Default color
	wc.lpszMenuName  = NULL;
	wc.lpszClassName = "MdiChildWndClass";
	if (!RegisterClass((LPWNDCLASS)&wc))
		return 0;

	return 1;
}
/*<---------------------------------------------------------------------->*/
/* Creates the frame */
static HWND CreateMdiClient(HWND hwndparent)
{
    CLIENTCREATESTRUCT ccs = {0};
    HWND hwndMDIClient;
    int icount = GetMenuItemCount(GetMenu(hwndparent));

    // Find window menu where children will be listed
    ccs.hWindowMenu  = GetSubMenu(GetMenu(hwndparent), icount-2);
    ccs.idFirstChild = IDM_WINDOWCHILD;

    // Create the MDI client filling the client area
    hwndMDIClient = CreateWindow("mdiclient",
                                 NULL,
                                 WS_CHILD | WS_CLIPCHILDREN | WS_VSCROLL | WS_VISIBLE |
                                 WS_HSCROLL,
                                 0, 0, 0, 0,
                                 hwndparent,
                                 (HMENU)0xCAC,
                                 gInst,
                                 (LPVOID)&ccs);

    ShowWindow(hwndMDIClient, SW_SHOW);

    return hwndMDIClient;
}
/*<---------------------------------------------------------------------->*/
HWND CreatemodelWndClassWnd(void)
{
   return CreateWindowEx(WS_EX_CLIENTEDGE,"MainWndClass",APP_NAME,
	WS_MINIMIZEBOX|WS_VISIBLE|WS_CLIPSIBLINGS|WS_CLIPCHILDREN|WS_MAXIMIZEBOX|WS_CAPTION|WS_BORDER|WS_SYSMENU|WS_THICKFRAME,
	CW_USEDEFAULT,0,DF_WIDTH,DF_HEIGHT,
	NULL,
	NULL,
	gInst,
	NULL);
}
/*@@1<-@@*/
/*<---------------------------------------------------------------------->*/
BOOL _stdcall AboutDlg(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam)
{
   switch(msg) {
      case WM_CLOSE:
         EndDialog(hwnd,0);
	 return 1;
      case WM_COMMAND:
         switch (LOWORD(wParam)) {
      case IDOK:
  	EndDialog(hwnd,1);
	return 1;
	}
	break;
   }
   return 0;
}
/*<---------------------------------------------------------------------->*/
HWND MDIBuildChild(char *title, int type)
{
	HWND  hwndChild;
	char  rgch[150];
	static int cUntitled;
	MDICREATESTRUCT mcs;
	POINT dimensions;

	if (title == NULL)
		wsprintf(rgch,"Untitled%d", cUntitled++);
	else {
		strncpy(rgch,title,149);
		rgch[149] = 0;
	}

	// Create the MDI child window

        mcs.szClass = "MdiChildWndClass";      // window class name
        mcs.szTitle = rgch;             // window title
        mcs.hOwner  = gInst;            // owner
        mcs.x       = CW_USEDEFAULT;    // x position
        mcs.y       = CW_USEDEFAULT;    // y position
    switch(type)
    {
		case IDD_SALESTR:
           mcs.cx = dimensions.x = 700;    // width
           mcs.cy = dimensions.y = 470;    // height
           break;
        case IDD_ITEMMAIN:
           mcs.cx = dimensions.x = 600;    // width
		   mcs.cy = dimensions.y = 475;    // height
           break;
        default:
           mcs.cx = dimensions.x = 600;    // width
		   mcs.cy = dimensions.y = 400;    // height
           break;
    }
        mcs.style   = 0;                // window style
        mcs.lParam  = type;                // lparam

        hwndChild = (HWND) SendMessage(hwndMDIClient,
                                       WM_MDICREATE,
                                       0,
                                       (LPARAM)(LPMDICREATESTRUCT) &mcs);

    SetWindowLong(hwndChild,GWL_USERDATA,(LONG) &dimensions);

	if (hwndChild != NULL)
		ShowWindow(hwndChild, SW_SHOW);

	return hwndChild;
}
/*<---------------------------------------------------------------------->*/
BOOL _stdcall UserDlg(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam)
{
   switch(msg)
   {
	  case WM_INITDIALOG:
	  {
	     /* Center this dialog on the screen */
	     RECT r;
	     POINT middle;
	     GetClientRect(hwndMain, &r);
	     middle.x = (r.right - r.left) / 2;
	     middle.y = (r.bottom - r.top) / 2;
	     MoveWindow(hwnd, middle.x-160, middle.y-118,320,235, TRUE);
	     break;
	  }
      case WM_CLOSE:
         EndDialog(hwnd,0);
	     return 1;
      case WM_COMMAND:
         switch (LOWORD(wParam))
         {
            case IDOK:
               GetDlgItemText(hwnd, IDC_USERNAME, loginID, 79);
  	           EndDialog(hwnd,1);
	           return 1;
	        case IDCANCEL:
	           EndDialog(hwnd,0);
	           if(bStartup == TRUE)
	              PostQuitMessage(0);
	           return 1;
	     }
	     break;
   }
   return 0;
}
/*<---------------------------------------------------------------------->*/
void MainWndProc_OnCommand(HWND hwnd, int id, HWND hwndCtl, UINT codeNotify)
{
   switch(id)
   {
      case IDM_FUSER:
         DialogBox(gInst,MAKEINTRESOURCE(IDD_USER), hwndMain, UserDlg);
         break;
      case IDM_FSETUP:
         Create_PropertySheet(hwnd, gInst);
         break;
      case IDM_SHIST:
         bsLook = TRUE;
         DialogBox(gInst, MAKEINTRESOURCE(IDD_SALESHIST), hwndMain, SalesLookupDlg);
		 break;
	  case IDM_STRANS:
	     bsLook = FALSE;
	     MDIBuildChild("Sales Transaction Window", IDD_SALESTR);
	     break;
	  case IDM_MIMAN:
		 MDIBuildChild("Item Maintenance", IDD_ITEMMAIN);
		 break;
      case IDM_RS:
		 ShellExecute(hwndMain, "open", reports1, NULL, NULL, SW_SHOWNORMAL);
		 break;
      case IDM_RI:
 		 ShellExecute(hwndMain, "open", reports2, NULL, NULL, SW_SHOWNORMAL);
 		 break;
      case IDM_RSTOCK:
 		 ShellExecute(hwndMain, "open", reports3, NULL, NULL, SW_SHOWNORMAL);
 		 break;
	  case IDM_MVMAN:
		 MDIBuildChild("Vendor Maintenance", IDD_VENDORMAIN);
		 break;
      case IDM_MCMAN:
 		 MDIBuildChild("Customer Maintenance", IDD_CUSTOMERMAIN);
		 break;
      case IDM_ABOUT:
		 DialogBox(gInst,MAKEINTRESOURCE(IDD_ABOUT),
			hwndMain,AboutDlg);
		 break;
	  case IDM_CONN:
		 ConnectDatabase(hwnd);
			break;
	  case IDM_DISC:
		 if(isConnected)
            FreeSQLEnvironment();
		 break;

		case IDM_WINDOWTILE:
		   SendMessage(hwndMDIClient,WM_MDITILE,0,0);
		   break;
		case IDM_WINDOWCASCADE:
		   SendMessage(hwndMDIClient,WM_MDICASCADE,0,0);
		   break;
		case IDM_WINDOWICONS:
		   SendMessage(hwndMDIClient,WM_MDIICONARRANGE,0,0);
		   break;
		case IDM_EXIT:
		   PostMessage(hwnd,WM_CLOSE,0,0);
		   break;
	}
}

/*<---------------------------------------------------------------------->*/
/*@@2->@@*/
LRESULT CALLBACK MainWndProc(HWND hwnd,UINT msg,WPARAM wParam,LPARAM lParam)
{
	switch (msg) {
		case WM_CREATE:
		   hwndMDIClient = CreateMdiClient(hwnd);
		   break;
	case WM_SIZE:
		SendMessage(hWndStatusbar,msg,wParam,lParam);
		InitializeStatusBar(hWndStatusbar,1);
		if (wParam != SIZE_MINIMIZED)
		{
		   RECT rc, rcClient;
		   GetClientRect(hwnd, &rcClient);
		   GetWindowRect(hWndStatusbar, &rc);
		   ScreenToClient(hwnd, (LPPOINT)&rc.left);
		   rcClient.bottom = rc.top;
		   MoveWindow(hwndMDIClient,rcClient.left,rcClient.top,rcClient.right-rcClient.left, rcClient.bottom-rcClient.top, TRUE);
		}
		return 0;
	case WM_MENUSELECT:
		return MsgMenuSelect(hwnd,msg,wParam,lParam);
	case WM_COMMAND:
		HANDLE_WM_COMMAND(hwnd,wParam,lParam,MainWndProc_OnCommand);
		break;
	case WM_DESTROY:
		PostQuitMessage(0);
		break;
	default:
		return DefFrameProc(hwnd,hwndMDIClient,msg,wParam,lParam);
	}
/*@@3<-@@*/
	return DefFrameProc(hwnd,hwndMDIClient,msg,wParam,lParam);
}

/*
 *  FUNCTION: MDIChildWndProc(HWND, UINT, WPARAM, LPARAM)
 *
 *  PURPOSE:  Processes messages for MDI child windows.
 *
 *  PARAMETERS:
 *    hwnd     - window handle
 *    uMessage - message number
 *    wparam   - additional information (dependant of message number)
 *    lparam   - additional information (dependant of message number)
 *
 *  RETURN VALUE:
 *    Depends on the message number.
*/
LRESULT CALLBACK MdiChildWndProc(HWND hwnd,UINT msg,WPARAM wparam,LPARAM lparam)
{
	switch(msg)
	{
	   case WM_CREATE:
	   {
		  int data, style;
		  data = ((MDICREATESTRUCT*)((CREATESTRUCT*)lparam)->lpCreateParams)->lParam;
		  style = GetWindowLong(hwnd, GWL_STYLE);
		  /* disable Maximize box and resizing, WS_THICKFRAME controls this
		     WS_MAXIMIZEBOX is obviously the Maximizing style. */
		  style = style & (~WS_MAXIMIZEBOX) & (~WS_THICKFRAME);
		  style = style | WS_BORDER;
		  SetWindowLong(hwnd, GWL_STYLE, style);
		  /* We should repaint here perhaps, so that the Window long gets set. */
		  UpdateWindow(hwnd);
		  /* Based on the type, build the right dialog */

		  switch(data)
		  {
			  case IDD_SALESTR:
			     CreateDialog(gInst, MAKEINTRESOURCE(data), hwnd, SalesMainDlg);
			     break;
			  case IDD_ITEMMAIN:
			     CreateDialog(gInst, MAKEINTRESOURCE(data), hwnd, ItemMainDlg);
			     break;
			  case IDD_VENDORMAIN:
			     CreateDialog(gInst, MAKEINTRESOURCE(data), hwnd, VendorMainDlg);
			     break;
			  case IDD_CUSTOMERMAIN:
			     CreateDialog(gInst, MAKEINTRESOURCE(data), hwnd, CustomerMainDlg);
			     break;
		  }
	   }
	   break;
	}
	return DefMDIChildProc(hwnd, msg, wparam, lparam);
}
/*<---------------------------------------------------------------------->*/
int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, INT nCmdShow)
{
	MSG msg;
	HANDLE hAccelTable;

	gInst = hInstance;
	bStartup = TRUE;
	if (!InitApplication())
		return 0;

	hAccelTable = LoadAccelerators(gInst,MAKEINTRESOURCE(IDACCEL));

	if ((hwndMain = CreatemodelWndClassWnd()) == (HWND)0)
		return 0;
	CreateSBar(hwndMain,"Ready",1);
	ShowWindow(hwndMain,SW_MAXIMIZE);
	DialogBox(gInst,MAKEINTRESOURCE(IDD_USER), hwndMain, UserDlg);
	bStartup = FALSE;
	/* initialize ODBC Driver Manager Interface */

	if (!Init_ODBCEnv()) {
      	MessageBox(hwndMain, "Failed to Initilize ODBC-Lib. Database may not be available.", APP_NAME, MB_OK|MB_ICONHAND);
      	useDatabase = FALSE;
	}

	setupReports();

	while (GetMessage(&msg,NULL,0,0)) {
		if (!TranslateMDISysAccel(hwndMain, &msg))
			if (!TranslateAccelerator(msg.hwnd, hAccelTable, &msg)) {
				TranslateMessage(&msg);  // Translates virtual key codes
				DispatchMessage(&msg);   // Dispatches message to window
			}
	}
	if(useDatabase)
	   FreeSQLEnvironment();

	return msg.wParam;
}

void setupReports()
{
	strcpy(reports1, "http://www.yahoo.com");
	strcpy(reports2, "http://www.google.com");
	strcpy(reports3, "http://www.csupomona.edu");
}
