/* items.c - Functions and routines pertaining to listing parts.

 * Copyright (c) 2005 Devin Smith
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:

 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.

 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.

*/

//#include "auto.h"
#include "items.h"
#include "apisres.h"

static int InitializeTB(HWND hDlg,WPARAM wParam, LPARAM lParam);
LRESULT CALLBACK ValidateWndProc(HWND hwnd,UINT msg,WPARAM wParam,LPARAM lParam);

static WNDPROC oldedit;
HWND thisDialog;

char item_num[80];

void DisplaySimpleItem();

BOOL _stdcall ItemLookupDlg(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam)
{

   HWND hlist = NULL;
   LV_COLUMN lvc;

	switch(msg) {
		case WM_INITDIALOG:
			hlist = GetDlgItem(hwnd,IDC_ITEMLIST);
			SendMessage(hlist, LVM_SETEXTENDEDLISTVIEWSTYLE, 0, LVS_EX_FULLROWSELECT | LVS_EX_GRIDLINES);
			lvc.mask = LVCF_TEXT|LVCF_WIDTH;
			lvc.pszText = "Item Number";
			lvc.cx = 146;
			ListView_InsertColumn(hlist, 0, &lvc);
			lvc.pszText = "Item Description";
			lvc.cx = 300;
			ListView_InsertColumn(hlist, 1, &lvc);
			lvc.pszText = "Quantity";
			lvc.cx = 150;
			ListView_InsertColumn(hlist, 2, &lvc);
			break;

		case WM_CLOSE:
			EndDialog(hwnd,0);
			return 1;
		case WM_COMMAND:
			switch (LOWORD(wParam)) {
				case IDOK:
					EndDialog(hwnd,1);
					return 1;
				case IDCANCEL:
					EndDialog(hwnd,0);
					return 1;

			}
			break;
	}
	return 0;
}

BOOL _stdcall ItemMainDlg(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam)
{
   HWND hLookup;
   HWND hEdit;
   HWND hComboBox;
   static HBITMAP hBitmap = NULL;
   switch (msg)
   {
      case WM_INITDIALOG:
      	 hLookup = GetDlgItem(hwnd, IDB_LOOK);
	  	 hBitmap = LoadBitmap(gInst, MAKEINTRESOURCE(IDB_LOOKUP));
	  	 thisDialog = hwnd;
	  	 SendMessage(hLookup, BM_SETIMAGE, IMAGE_BITMAP, (LPARAM) hBitmap);

         InitializeTB(hwnd, wParam, lParam);

         hEdit = GetDlgItem(hwnd, IDC_ITEMNUM);
         oldedit = (WNDPROC) SetWindowLong (hEdit, GWL_WNDPROC, (LONG) ValidateWndProc) ;

         hComboBox = GetDlgItem(hwnd, IDC_ITEMTYPE);

         SendMessage(hComboBox, CB_ADDSTRING, 0, (LPARAM) "Accesories");
		 SendMessage(hComboBox, CB_ADDSTRING, 0, (LPARAM) "Engine");
		 SendMessage(hComboBox, CB_ADDSTRING, 0, (LPARAM) "Misc.");


         //GetFocus();
         SetFocus(hEdit);
         //GetFocus();

         //SendMessage(hwnd, WM_NEXTDLGCTL, (WPARAM) hEdit, TRUE);

         return FALSE;
      case WM_COMMAND:
         switch (LOWORD(wParam))
	     {
	        case IDB_LOOK:
	          DialogBox(gInst,MAKEINTRESOURCE(IDD_ITEMLIST), hwnd, ItemLookupDlg);
	          return 1;
	        case IDB_SAVE:
	          MessageBox(hwnd, "Can't save! No database connection", APP_NAME, MB_OK);
	          return 1;
	     }
	 break;
	 /* By default, WM_CLOSE is equivalent to CANCEL */
	case WM_CLOSE:
	   if(hBitmap)
	     DeleteObject(hBitmap);
	   EndDialog(hwnd,0);
	   return TRUE;
   }
   return FALSE;
}


static int InitializeTB(HWND hDlg,WPARAM wParam, LPARAM lParam)
{
   HWND hTool;
   TBBUTTON tbb[5];
   TBADDBITMAP tbab;
   UINT offsetImage;

   hTool = GetDlgItem(hDlg, IDD_TOOLBAR);
   SendMessage(hTool, TB_BUTTONSTRUCTSIZE, (WPARAM)sizeof(TBBUTTON), 0);
   tbab.hInst = gInst;
   tbab.nID = IDB_TBAR;
   offsetImage = SendMessage(hTool, TB_ADDBITMAP, 3, (LPARAM)&tbab);

   ZeroMemory(tbb, sizeof(tbb));
   tbb[0].iBitmap = offsetImage;
   tbb[0].fsState = TBSTATE_ENABLED;
   tbb[0].fsStyle = TBSTYLE_BUTTON;
   tbb[0].idCommand = IDB_SAVE;
   tbb[0].iString = (INT_PTR) "Save";

   tbb[1].iBitmap = 0;
   tbb[1].fsState = TBSTATE_ENABLED;
   tbb[1].fsStyle = TBSTYLE_SEP;
   tbb[1].idCommand = 0;

   tbb[2].iBitmap = offsetImage + 2;
   tbb[2].fsState = TBSTATE_ENABLED;
   tbb[2].fsStyle = TBSTYLE_BUTTON;
   tbb[2].idCommand = 0;
   tbb[2].iString = (INT_PTR) "Clear";

   tbb[3].iBitmap = 0;
   tbb[3].fsState = TBSTATE_ENABLED;
   tbb[3].fsStyle = TBSTYLE_SEP;
   tbb[3].idCommand = 0;

   tbb[4].iBitmap = offsetImage + 1;
   tbb[4].fsState = TBSTATE_ENABLED;
   tbb[4].fsStyle = TBSTYLE_BUTTON;
   tbb[4].idCommand = 0;
   tbb[4].iString = (INT_PTR) "Delete";

   SendMessage(hTool, TB_ADDBUTTONS, sizeof(tbb)/sizeof(TBBUTTON), (LPARAM)&tbb);
   return 1;
}

LRESULT CALLBACK ValidateWndProc (HWND hwnd, UINT message,
                           WPARAM wParam, LPARAM lParam)
{
	 switch(message)
	 {
		 case WM_CHAR:
	 		{
				if (wParam == VK_TAB)
			    {
					GetDlgItemText(thisDialog, IDC_ITEMNUM, item_num, 79);
					item_num[79] = 0;
					if(strcmp(item_num, "001") == 0)
					{
						DisplaySimpleItem();
					}
					return 1;
	   	        }
			}
		}

	return CallWindowProc (oldedit, hwnd, message, wParam, lParam) ;
}

void DisplaySimpleItem()
{
	HBITMAP ourpic;
    SetDlgItemText(thisDialog, IDC_ITEMSDESC, "Universal Wiperblade");
    SetDlgItemText(thisDialog, IDC_ITEMSW, "0.5 lb.");
    SetDlgItemText(thisDialog, IDC_ITEMSC, "$1.19");
    SendMessage(GetDlgItem(thisDialog, IDC_ITEMTYPE), CB_SELECTSTRING, 1, (LPARAM) "Misc.");
    SetDlgItemText(thisDialog, IDC_ITEMTYPE, "Accesories");
    SetDlgItemText(thisDialog, IDC_ITEMCC, "$1.99");
    SetDlgItemText(thisDialog, IDC_ITEMDES, "Standard Univsal Wiperblade. Fits most cars. 1 year warrenty.");
    SetDlgItemText(thisDialog, IDC_ITEMQA, "190");
    SetDlgItemText(thisDialog, IDC_ITEMQH, "30");
//    ourpic = LoadBitmap(gInst, MAKEINTRESOURCE(IDB_LOOKUP));
//    SendMessage(GetDlgItem(thisDialog, IDC_ITEMPIC), BM_SETIMAGE, IMAGE_BITMAP, (LPARAM) ourpic);


}
