/* ODBC - Functions and routines pertaining to ODBC drivers

 * Copyright (c) 2005 Devin Smith
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:

 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.

 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.

 */
#include "auto.h"
#include "odbc.h"
#include <stdio.h>


BOOL FAR PASCAL Init_ODBCEnv()
{

if (SQLAllocHandle(SQL_HANDLE_ENV,SQL_NULL_HANDLE,&henv) != SQL_SUCCESS)
      return FALSE;

return (SQLSetEnvAttr(henv, SQL_ATTR_ODBC_VERSION,
                         (SQLPOINTER) SQL_OV_ODBC3, SQL_IS_INTEGER) == SQL_SUCCESS);

}

BOOL FAR PASCAL FreeSQLEnvironment()
{
   /* Free up all ODBC related resources */
   return (SQLFreeHandle(SQL_HANDLE_ENV,henv) == SQL_SUCCESS);

}

BOOL FAR PASCAL ConnectDatabase(HWND hWnd)
{
   	char      szBuffer[257];  /* buffer to display successful connection on hdbc combo-box */
   	SQLRETURN nResult;        /* Result code */

	/* Allocate a new SQLHDBC. If successful then call SQLConnect using the
	   allocated hdbc and supplied connection information. */

	if ((nResult = SQLAllocHandle(SQL_HANDLE_DBC,henv, (SQLHDBC FAR *)&hdbc)) != SQL_SUCCESS) {
      	DisplayError(nResult, hWnd, SQL_HANDLE_ENV, henv);
	      return (FALSE);
	   }

   nResult = SQLConnect(hdbc,(SQLCHAR*) "SQLSERVER",SQL_NTS,(SQLCHAR*)"sa",SQL_NTS,(SQLCHAR*)"password",SQL_NTS);
	// if failed to connect, free the allocated hdbc before return
   if (nResult != SQL_SUCCESS && nResult != SQL_SUCCESS_WITH_INFO) {
      DisplayError(nResult, hWnd, SQL_HANDLE_DBC, hdbc);
      SQLFreeHandle(SQL_HANDLE_DBC,hdbc);
      return (FALSE);
   }

	// display any connection information if driver returns SQL_SUCCESS_WITH_INFO
   if (nResult == SQL_SUCCESS_WITH_INFO)
      DisplayError(nResult, hWnd, SQL_HANDLE_DBC, hdbc);

	return (TRUE);

}

void FAR PASCAL FreeConnect()
{

SQLDisconnect(hdbc);
SQLFreeHandle(SQL_HANDLE_DBC,hdbc);


}


/*
    FUNCTION: DisplayError(SQLRETURN nResult, HWND hWnd, SWORD fHandleType, SQLHANDLE handle)
    COMMENTS: Format and display errors or warnings.
*/

void FAR PASCAL DisplayError(SQLRETURN nResult, HWND hWnd, SWORD fHandleType, SQLHANDLE handle)
{
   UCHAR    szErrState[SQL_SQLSTATE_SIZE+1];    // SQL Error State string
   UCHAR    szErrText[SQL_MAX_MESSAGE_LENGTH+1];    // SQL Error Text string
   char szBuffer[SQL_SQLSTATE_SIZE+SQL_MAX_MESSAGE_LENGTH+MAXBUFLEN+1];
   // formatted Error text Buffer
   SWORD    wErrMsgLen;             // Error message length
   UDWORD   dwErrCode;              // Native Error code
   int  iSize;                      // Display Error Text size
   SQLRETURN  nErrResult;             // Return Code from SQLGetDiagRec
   SWORD sMsgNum = 1;
   SWORD fFirstRun = TRUE;

   szBuffer[0] = '\0';

   do
      {
         // continue to bring messageboxes till all errors are displayed.
         // more than one message box may be reqd. as err text has fixed
         // string size.

         // initialize display buffer with the string in error text buffer
         strcpy(szDispBuffer, szBuffer);

         // call SQLGetDiagRec function with proper ODBC handles, repeatedly until
         // function returns SQL_NO_DATA. Concatenate all error strings
         // in the display buffer and display all results.
         while ((nErrResult = SQLGetDiagRec(fHandleType, handle, sMsgNum++,
                                            szErrState, &dwErrCode, szErrText,
                                            SQL_MAX_MESSAGE_LENGTH-1, &wErrMsgLen))
                != SQL_NO_DATA) {


				if(nErrResult == SQL_ERROR || nErrResult == SQL_INVALID_HANDLE)
					break;

            wsprintf(szBuffer, SQLERR_FORMAT, (LPSTR)szErrState, dwErrCode, (LPSTR)szErrText);
            iSize = strlen(szDispBuffer);
            if (iSize && (iSize+strlen(szBuffer)+1) >= MAXDISPLAYSIZE)
               break;
            if (iSize)
               strcat(szDispBuffer, "\n");
            strcat(szDispBuffer, szBuffer);
         }

         // display proper ERROR or WARNING message with proper title

         if (nResult == SQL_SUCCESS_WITH_INFO)
            MessageBox(hWnd, szDispBuffer, (fFirstRun? SQLWRNMSGTITLE : SQLWRNCNTDTITLE),
                       MB_OK | MB_ICONINFORMATION);
         else
            MessageBox(hWnd, szDispBuffer, (fFirstRun? SQLERRMSGTITLE : SQLERRCNTDTITLE),
                       MB_OK | MB_ICONEXCLAMATION);

         if (fFirstRun)
            fFirstRun = FALSE;
      }
   while (!(nErrResult == SQL_NO_DATA || nErrResult == SQL_ERROR || nErrResult == SQL_INVALID_HANDLE));
}


int RunQuery(HWND hWnd)
{

SQLHSTMT  hstmt;                      /* hstmt for query */
SQLRETURN nResult;        /* Result code */
SQLINTEGER sModID, cbModID;

char testbuffer[400];

					MessageBox(hWnd, "test3", "test2", MB_OK);


SQLAllocHandle(SQL_HANDLE_STMT,hdbc, &hstmt);

/* SQLPrepare(hstmt, "UPDATE Parts SET Price = ? WHERE PartID = ?", SQL_NTS);
*/
nResult = SQLExecDirect( hstmt, "SELECT * FROM MKT..MOTRAN01 WHERE MONO = '6014'", SQL_NTS);

if (nResult != SQL_SUCCESS && nResult != SQL_SUCCESS_WITH_INFO) {
      DisplayError(nResult, hWnd, SQL_HANDLE_STMT, hstmt);
	return FALSE;
}

SQLBindCol(hstmt, 1, SQL_C_ULONG, &sModID, 0, &cbModID);
SQLFetch(hstmt);

sprintf(testbuffer, "The number is %d", sModID) ;

MessageBox(hWnd, testbuffer, "Title", MB_OK);

SQLCloseCursor(hstmt);
SQLFreeHandle(SQL_HANDLE_STMT, hstmt);

return TRUE;

}
