/* sales.c - Functions and routines pertaining to listing parts.

 * Copyright (c) 2005 Devin Smith
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:

 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.

 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.

*/

#include "sales.h"
#include "apisres.h"

static int InitializeTB(HWND hDlg,WPARAM wParam, LPARAM lParam);
static void BuildItemListView(HWND hwnd);


BOOL _stdcall SalesLookupDlg(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam)
{

   HWND hlist = NULL;
   LV_COLUMN lvc;

	switch(msg) {
		case WM_INITDIALOG:
			hlist = GetDlgItem(hwnd,IDC_ITEMLIST);
			SendMessage(hlist, LVM_SETEXTENDEDLISTVIEWSTYLE, 0, LVS_EX_FULLROWSELECT | LVS_EX_GRIDLINES);
			lvc.mask = LVCF_TEXT|LVCF_WIDTH;
			lvc.pszText = "Document Num";
			lvc.cx = 146;
			ListView_InsertColumn(hlist, 0, &lvc);
			lvc.pszText = "Type";
			lvc.cx = 300;
			ListView_InsertColumn(hlist, 1, &lvc);
			lvc.pszText = "Customer";
			lvc.cx = 150;
			ListView_InsertColumn(hlist, 2, &lvc);
			break;

		case WM_CLOSE:
			EndDialog(hwnd,0);
			return 1;
		case WM_COMMAND:
			switch (LOWORD(wParam)) {
				case IDOK:
					EndDialog(hwnd,1);
					if(bsLook)
					{
						// launch the MDI client.
						MDIBuildChild("Sales Transaction Window", IDD_SALESTR);
						bsLook = FALSE;
					}
					return 1;
				case IDCANCEL:
					EndDialog(hwnd,0);
					return 1;

			}
			break;
	}
	return 0;
}

BOOL _stdcall SalesMainDlg(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam)
{
   HWND hLookup;
   HWND hComboBox;
   static HBITMAP hBitmap = NULL;
   switch (msg)
   {
      case WM_INITDIALOG:
      	 hLookup = GetDlgItem(hwnd, IDB_LOOK);
	  	 hBitmap = LoadBitmap(gInst, MAKEINTRESOURCE(IDB_LOOKUP));
	  	 SendMessage(hLookup, BM_SETIMAGE, IMAGE_BITMAP, (LPARAM) hBitmap);

	  	 SetDlgItemText(hwnd, IDC_SITEID, "WAREHOUSE");

         InitializeTB(hwnd, wParam, lParam);
         /* Build Item listview */
         BuildItemListView(hwnd);

         hComboBox = GetDlgItem(hwnd, IDC_ITEMTYPE);

         SendMessage(hComboBox, CB_ADDSTRING, 0, (LPARAM) "Invoice");
         SendMessage(hComboBox, CB_ADDSTRING, 0, (LPARAM) "Quote");
         SendMessage(hComboBox, CB_ADDSTRING, 0, (LPARAM) "Return");

         return TRUE;
         /* By default, IDOK means close this dialog returning 1, IDCANCEL means
            close this dialog returning zero
          */
      case WM_COMMAND:
         switch (LOWORD(wParam))
	     {
	        case IDB_LOOK:
	          DialogBox(gInst,MAKEINTRESOURCE(IDD_SALESHIST), hwnd, SalesLookupDlg);
	          return 1;
	          /*
	        case IDCANCEL:
	          EndDialog(hwnd,0);
	          return 1;*/
	     }
	 break;
	 /* By default, WM_CLOSE is equivalent to CANCEL */
	case WM_CLOSE:
	   if(hBitmap)
	     DeleteObject(hBitmap);
	   EndDialog(hwnd,0);
	   return TRUE;
   }
   return FALSE;
}


static int InitializeTB(HWND hDlg,WPARAM wParam, LPARAM lParam)
{
   HWND hTool;
   TBBUTTON tbb[5];
   TBADDBITMAP tbab;
   UINT offsetImage;

   hTool = GetDlgItem(hDlg, IDD_TOOLBAR);
   SendMessage(hTool, TB_BUTTONSTRUCTSIZE, (WPARAM)sizeof(TBBUTTON), 0);
   tbab.hInst = gInst;
   tbab.nID = IDB_TBAR;
   offsetImage = SendMessage(hTool, TB_ADDBITMAP, 4, (LPARAM)&tbab);

   ZeroMemory(tbb, sizeof(tbb));
   tbb[0].iBitmap = offsetImage;
   tbb[0].fsState = TBSTATE_ENABLED;
   tbb[0].fsStyle = TBSTYLE_BUTTON;
   tbb[0].idCommand = 0;
   tbb[0].iString = (INT_PTR) "Save";

   tbb[1].iBitmap = 0;
   tbb[1].fsState = TBSTATE_ENABLED;
   tbb[1].fsStyle = TBSTYLE_SEP;
   tbb[1].idCommand = 0;

   tbb[2].iBitmap = offsetImage + 1;
   tbb[2].fsState = TBSTATE_ENABLED;
   tbb[2].fsStyle = TBSTYLE_BUTTON;
   tbb[2].idCommand = 0;
   tbb[2].iString = (INT_PTR) "Delete";

   tbb[3].iBitmap = 0;
   tbb[3].fsState = TBSTATE_ENABLED;
   tbb[3].fsStyle = TBSTYLE_SEP;
   tbb[3].idCommand = 0;

   tbb[4].iBitmap = offsetImage + 3;
   tbb[4].fsState = TBSTATE_ENABLED;
   tbb[4].fsStyle = TBSTYLE_BUTTON;
   tbb[4].idCommand = 0;
   tbb[4].iString = (INT_PTR) "Void";

   SendMessage(hTool, TB_ADDBUTTONS, sizeof(tbb)/sizeof(TBBUTTON), (LPARAM)&tbb);
   return 1;
}

static void BuildItemListView(HWND hwnd)
{
   HWND hlist = NULL;
   LV_COLUMN lvc;

   hlist = GetDlgItem(hwnd,IDC_ITEMLIST);
   SendMessage(hlist, LVM_SETEXTENDEDLISTVIEWSTYLE, 0, LVS_EX_FULLROWSELECT | LVS_EX_GRIDLINES);
   lvc.mask = LVCF_TEXT|LVCF_WIDTH;
   lvc.pszText = "Item Number";
   lvc.cx = 146;
   ListView_InsertColumn(hlist, 0, &lvc);
   lvc.pszText = "Item Description";
   lvc.cx = 200;
   ListView_InsertColumn(hlist, 1, &lvc);
   lvc.pszText = "Quantity";
   lvc.cx = 150;
   ListView_InsertColumn(hlist, 2, &lvc);
   lvc.pszText = "Unit Price";
   lvc.cx = 150;
   ListView_InsertColumn(hlist, 3, &lvc);

}
